==> nezha-compute-common-1.19.2066-20180919.153831-2-sources.jar: cn/com/duiba/nezha/compute/common/model/activityselectconversion/ActivityModel.java <==
package cn.com.duiba.nezha.compute.common.model.activityselectconversion;

public class ActivityModel {
    long activityId;
    long slotId;
    long appId;
    long activityType; //活动类型 **new**
    double alpha = 1.5; //模型参数
    double beta = 2; // 模型参数
    double reward = 0; //模型参数
    double count = 0; //模型参数
    double changeScore;//模型参数

    public long getActivityId() {
        return activityId;
    }

    public void setActivityId(long activityId) {
        this.activityId = activityId;
    }

    public long getSlotId() {
        return slotId;
    }

    public void setSlotId(long slotId) {
        this.slotId = slotId;
    }

    public long getAppId() {
        return appId;
    }

    public void setAppId(long appId) {
        this.appId = appId;
    }


    public long getActivityType() {
        return activityType;
    }

    public void setActivityType(long activityType) {
        this.activityType = activityType;
    }

    public double getAlpha() {
        return alpha;
    }

    public void setAlpha(double alpha) {
        this.alpha = alpha;
    }

    public double getBeta() {
        return beta;
    }

    public void setBeta(double beta) {
        this.beta = beta;
    }

    public double getReward() {
        return reward;
    }

    public void setReward(double reward) {
        this.reward = reward;
    }

    public double getCount() {
        return count;
    }

    public void setCount(double count) {
        this.count = count;
    }

    public double getChangeScore() {
        return changeScore;
    }

    public void setChangeScore(double changeScore) {
        this.changeScore = changeScore;
    }
}

==> nezha-compute-common-1.27.1002-20181227.121147-1-sources.jar: cn/com/duiba/nezha/compute/common/model/activityselectconversion/ActivityModel.java <==
package cn.com.duiba.nezha.compute.common.model.activityselectconversion;

public class ActivityModel {
    long activityId;
    long slotId;
    long appId;
    long activityType; //活动类型 **new**
    double alpha = 1.5; //模型参数
    double beta = 2; // 模型参数
    double reward = 0; //模型参数
    double count = 0; //模型参数
    double changeScore = 0;//模型参数
    long updateTime = 0;//修改时间

    public long getActivityId() {
        return activityId;
    }

    public void setActivityId(long activityId) {
        this.activityId = activityId;
    }

    public long getSlotId() {
        return slotId;
    }

    public void setSlotId(long slotId) {
        this.slotId = slotId;
    }

    public long getAppId() {
        return appId;
    }

    public void setAppId(long appId) {
        this.appId = appId;
    }


    public long getActivityType() {
        return activityType;
    }

    public void setActivityType(long activityType) {
        this.activityType = activityType;
    }

    public double getAlpha() {
        return alpha;
    }

    public void setAlpha(double alpha) {
        this.alpha = alpha;
    }

    public double getBeta() {
        return beta;
    }

    public void setBeta(double beta) {
        this.beta = beta;
    }

    public double getReward() {
        return reward;
    }

    public void setReward(double reward) {
        this.reward = reward;
    }

    public double getCount() {
        return count;
    }

    public void setCount(double count) {
        this.count = count;
    }

    public double getChangeScore() {
        return changeScore;
    }

    public void setChangeScore(double changeScore) {
        this.changeScore = changeScore;
    }

    public long getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(long updateTime) {
        this.updateTime = updateTime;
    }

}
